<?php

/**
 * @file
 * Provides metadata for the line item entity.
 */

/**
 * Implements hook_entity_property_info().
 */
function studyroom_space_entity_property_info() {
  $info = array();

  // Add meta-data about the basic commerce_line_item properties.
  $properties = &$info['studyroom_space']['properties'];

  $properties['space_id'] = array(
    'label' => t('Space ID'),
    'description' => t('The internal numeric ID of the space.'),
    'type' => 'integer',
    'schema field' => 'space_id',
  );
  $properties['type'] = array(
    'label' => t('Type'),
    'description' => t('The location of this space.'),
    'type' => 'token',
    'setter callback' => 'entity_property_verbatim_set',
    'options list' => 'entity_metadata_field_options_list',
    'required' => TRUE,
    'schema field' => 'type',
  );
  $properties['language'] = array(
    'label' => t('Language'),
    'type' => 'token',
    'description' => t('The language the space was created in.'),
    'setter callback' => 'entity_property_verbatim_set',
    'options list' => 'entity_metadata_language_list',
    'schema field' => 'language',
    // 'setter permission' => 'administer commerce_product entities',
  );
  $properties['description'] = array(
    'label' => t('Description'),
    'description' => t('The description of this space.'),
    'type' => 'text',
    'setter callback' => 'entity_property_verbatim_set',
    'required' => FALSE,
    'schema field' => 'description',
  );
  $properties['name'] = array(
    'label' => t('Space label'),
    'description' => t('The label displayed with this space.'),
    'type' => 'text',
    'setter callback' => 'entity_property_verbatim_set',
    'required' => TRUE,
    'schema field' => 'name',
  );
  $properties['capacity'] = array(
    'label' => t('capacity'),
    'description' => t('The capacity of this space.'),
    'type' => 'integer',
    'getter callback' => 'entity_property_verbatim_get',
    'setter callback' => 'entity_property_verbatim_set',
    'required' => TRUE,
    'schema field' => 'capacity',
  );
  $properties['created'] = array(
    'label' => t('Date created'),
    'description' => t('The date the space was created.'),
    'type' => 'date',
    'setter callback' => 'entity_metadata_verbatim_set',
    // 'setter permission' => 'administer line items',
    'schema field' => 'created',
  );
  $properties['changed'] = array(
    'label' => t('Date changed'),
    'description' => t('The date the space was most recently updated.'),
    'type' => 'date',
    'schema field' => 'changed',
  );
  $properties['status'] = array(
    'label' => t("Status"),
    'description' => t("Whether the space is published or unpublished."),
    'type' => 'integer',
    'options list' => 'entity_metadata_status_options_list',
    'setter callback' => 'entity_property_verbatim_set',
    'schema field' => 'status',
  );

  return $info;
}
